import hashlib
from Crypto.Cipher import AES
from Crypto.Util.Padding import pad, unpad
from binascii import b2a_hex, a2b_hex
from base64 import b64encode, b64decode

BLOCK_SIZE = 16


def encrypt(data: bytes, key: str = None, mode=AES.MODE_ECB, block_size=BLOCK_SIZE):
    """
    按照给定的秘钥 AES 加密data
    :param data: 内容的字节流
    :param key:  秘钥
    :param mode: AES 加密类型
    :param block_size: 加密长度 It must be 16, 24 or 32 bytes long (respectively for *AES-128*,
        *AES-192* or *AES-256*)
    :return:
    """
    assert key is not None and len(key.strip()) > 0, "加密秘钥 key 不能 None 或者空字符"

    data = pad(data, block_size)
    key = pad(key.encode(encoding='utf-8'), block_size)

    cipher = AES.new(key, mode)
    # 为了避免结果直接保存出现编码转换问题，这里选择转换成hex来存
    return b2a_hex(cipher.encrypt(data))


def encrypt_file(file_path: str, key=None):
    """
    返回给定文件的加密内容，用户拿到之后可以按照自己的喜好保存
    :param file_path: 要加密的文件路径
    :param key: 加密秘钥
    :return: 加密后的文件内容的字节流
    """
    assert key is not None and len(key.strip()) > 0, "加密秘钥 key 不能 None 或者空字符"
    return encrypt(open(file_path, mode='rb').read(), key)


def decrypt(encrypted_data: bytes, key: str = None, mode=AES.MODE_ECB, block_size=BLOCK_SIZE):
    # 吧16进制转成2进制再处理
    assert key is not None and len(key.strip()) > 0, "加密秘钥 key 不能 None 或者空字符"

    key = pad(key.encode(encoding='utf-8'), block_size)
    cipher = AES.new(key, mode)

    encrypted_data = a2b_hex(encrypted_data)
    return unpad(cipher.decrypt(encrypted_data), block_size)


def md5(text: str, encoding="utf-8"):
    return hashlib.md5(text.encode(encoding)).hexdigest()


if __name__ == '__main__':
    pass
    # key = "shirkhan"
    # txt = b'hello world'
    # enc = encrypt(txt, key)
    # print(enc)
    # print(encrypt(txt, key))
    # print(decrypt(enc,key).decode())

    # path = './shir_encryption.py'
    # print(encrypt_file(path, key))



import re

from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

with open("shirkhan/__init__.py", encoding="utf8") as f:
    version = re.search(r'__version__ = "(.*?)"', f.read()).group(1)

"""
备注:

easy_install的配置文件是~/.pydistutils.cfg，在其中指定index-url即可避免访问官方PyPI。 以下以阿里源为例。
[easy_install]
index-url=http://mirrors.aliyun.com/pypi/simple/
"""
setup(
    name="shirkhan",
    version=version,
    author="shirkhan",
    author_email="uybabbage@hotmail.com",
    description="shirkhan tools",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ishirkhan",
    packages=find_packages(),
    install_requires=[
        'pycryptodome==3.10.1',
        'xlrd==2.0.1',
        'openpyxl==3.0.7',
        'praatio==4.2.1'
    ],
    extras_require={
        'shirkhan_extra': ['pydub==0.25.1']
    },
    tests_require=[
        'pytest==6.2.4'
    ],
    setup_requires=[
        'wheel',
        'twine'
    ],
    classifiers=[
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)



alphabet = "".join(["ئ", "ا", "ە", "ب", "پ", "ت", "ج", "چ", "خ", "د", "ر", "ز", "ژ", "س", "ش", "غ", "ف", "ق",
                    "ك", "گ", "ل", "ڭ", "م", "ن", "ھ", "و", "ۇ", "ۆ", "ۈ", "ۋ", "ې", "ى", "ي"])
codebook = "".join(["q", "w", "e", "r", "t", "y", "u", "i", "o", "p", "a", "s", "d", "f", "g", "h", "j", "k", "l",
                    "z", "x", "c", "v", "b", "n", "m", "7", "6", "5", "4", "3", "2", "1"])


def encode(target_contents: str):
    """
    shirkhan 加密器
    :param target_contents:
    :return:
    """
    for i in range(0, len(alphabet)):
        target_contents = target_contents.replace(alphabet[i], codebook[i])
    return target_contents


def decode(target_contents: str):
    """
    shirkhan 加密对应的解码器
    :param target_contents:
    :return:
    """
    for i in range(0, len(alphabet)):
        target_contents = target_contents.replace(codebook[i], alphabet[i])
    return target_contents


if __name__ == '__main__':
    pass
    # target_context = "سالام دۇنيا"
    # encode_example = encode(target_context)
    # print("target_context,encode_example", target_context, " ---", encode_example)
    #
    # print("---" * 20)
    # decode_example = decode(encode_example)
    # print("encode_example,decoded_example", encode_example, " ---", decode_example)
